@@ -290,9 +290,9 @@
 #    define QT_NO_TEMPLATE_VARIANT
 /* Wcc does not fill in functions needed by valuelists, maps, and
    valuestacks implicitly */
-#    define Q_FULL_TEMPLATE_INSTANTIATION
+#    define TQ_FULL_TEMPLATE_INSTANTIATION
 /* can we just compare the structures? */
-#    define Q_FULL_TEMPLATE_INSTANTIATION_MEMCMP
+#    define TQ_FULL_TEMPLATE_INSTANTIATION_MEMCMP
 /* these are not useful to our customers */
 #    define QT_QWS_NO_SHM
 #    define QT_NO_QWS_MULTIPROCESS
@@ -304,7 +304,7 @@
 #  define Q_CC_GNU
 #  define Q_C_CALLBACKS
 #  if __GNUC__ == 2 && __GNUC_MINOR__ <= 7
-#    define Q_FULL_TEMPLATE_INSTANTIATION
+#    define TQ_FULL_TEMPLATE_INSTANTIATION
 #  endif
 /* GCC 2.95 knows "using" but does not support it correctly */
 #  if __GNUC__ == 2 && __GNUC_MINOR__ <= 95
@@ -354,7 +354,7 @@
               but it is not defined on older compilers like C Set 3.1 */
 #elif defined(__xlC__)
 #  define Q_CC_XLC
-#  define Q_FULL_TEMPLATE_INSTANTIATION
+#  define TQ_FULL_TEMPLATE_INSTANTIATION
 #  if __xlC__ < 0x400
 #    define Q_NO_BOOL_TYPE
 #    define Q_NO_EXPLICIT_KEYWORD
@@ -538,7 +538,7 @@
 #  else
 #    define Q_CC_HP
 #    define Q_NO_BOOL_TYPE
-#    define Q_FULL_TEMPLATE_INSTANTIATION
+#    define TQ_FULL_TEMPLATE_INSTANTIATION
 #    define Q_BROKEN_TEMPLATE_SPECIALIZATION
 #    define Q_NO_EXPLICIT_KEYWORD
 #  endif
@@ -1095,7 +1095,7 @@ Q_EXPORT const char *tqInstallPathShare();
  Just in case other code relies on it we better trigger a warning
  mandating a real implementation.
 */
-#ifdef Q_FULL_TEMPLATE_INSTANTIATION
+#ifdef TQ_FULL_TEMPLATE_INSTANTIATION
 #  define Q_DUMMY_COMPARISON_OPERATOR(C) \
     bool operator==( const C& ) const { \
         tqWarning( #C"::operator==( const "#C"& ) got called." ); \
