@@ -350,7 +350,7 @@ TQLNode *TQGList::locate( uint index )
 	curNode	 = firstNode;
 	curIndex = 0;
     }
-    register TQLNode *node;
+    TQLNode *node;
     int	 distance = index - curIndex;		// node distance to cur node
     bool forward;				// direction to traverse
 
@@ -405,7 +405,7 @@ void TQGList::inSort( TQPtrCollection::Item d )
     //mutex->lock();
 #endif
     int index = 0;
-    register TQLNode *n = firstNode;
+    TQLNode *n = firstNode;
     while ( n && compareItems(n->data,d) < 0 ){ // find position in list
 	n = n->next;
 	index++;
@@ -426,7 +426,7 @@ void TQGList::prepend( TQPtrCollection::Item d )
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n = new TQLNode( newItem(d) );
+    TQLNode *n = new TQLNode( newItem(d) );
     TQ_CHECK_PTR( n );
     n->prev = 0;
     if ( (n->next = firstNode) )		// list is not empty
@@ -451,7 +451,7 @@ void TQGList::append( TQPtrCollection::Item d )
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n = new TQLNode( newItem(d) );
+    TQLNode *n = new TQLNode( newItem(d) );
     TQ_CHECK_PTR( n );
     n->next = 0;
     if ( (n->prev = lastNode) ) {		// list is not empty
@@ -500,7 +500,7 @@ bool TQGList::insertAt( uint index, TQPtrCollection::Item d )
 	return FALSE;
     }
     TQLNode *prevNode = nextNode->prev;
-    register TQLNode *n = new TQLNode( newItem(d) );
+    TQLNode *n = new TQLNode( newItem(d) );
     TQ_CHECK_PTR( n );
     nextNode->prev = n;
     Q_ASSERT( (!((curIndex > 0) && (!prevNode))) );
@@ -564,7 +564,7 @@ TQLNode *TQGList::unlink()
 #endif
 	return 0;
     }
-    register TQLNode *n = curNode;		// unlink this node
+    TQLNode *n = curNode;		// unlink this node
     if ( n == firstNode ) {			// removing first node ?
 	if ( (firstNode = n->next) ) {
 	    firstNode->prev = 0;
@@ -881,7 +881,7 @@ void TQGList::clear()
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n = firstNode;
+    TQLNode *n = firstNode;
 
     firstNode = lastNode = curNode = 0;		// initialize list
     numNodes = 0;
@@ -914,7 +914,7 @@ int TQGList::findRef( TQPtrCollection::Item d, bool fromStart )
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n;
+    TQLNode *n;
     int	     index;
     if ( fromStart ) {				// start from first node
 	n = firstNode;
@@ -946,7 +946,7 @@ int TQGList::find( TQPtrCollection::Item d, bool fromStart )
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n;
+    TQLNode *n;
     int	     index;
     if ( fromStart ) {				// start from first node
 	n = firstNode;
@@ -977,7 +977,7 @@ uint TQGList::containsRef( TQPtrCollection::Item d ) const
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n = firstNode;
+    TQLNode *n = firstNode;
     uint     count = 0;
     while ( n ) {				// for all nodes...
 	if ( n->data == d )			// count # exact matches
@@ -1000,7 +1000,7 @@ uint TQGList::contains( TQPtrCollection::Item d ) const
 #if defined(QT_THREAD_SUPPORT)
     //mutex->lock();
 #endif
-    register TQLNode *n = firstNode;
+    TQLNode *n = firstNode;
     uint     count = 0;
     TQGList  *that = (TQGList*)this;		// mutable for compareItems()
     while ( n ) {				// for all nodes...
@@ -1167,7 +1167,7 @@ void TQGList::toVector( TQGVector *vector ) const
 #endif
 	return;
     }
-    register TQLNode *n = firstNode;
+    TQLNode *n = firstNode;
     uint i = 0;
     while ( n ) {
 	vector->insert( i, n->data );
